@@ -48,14 +48,15 @@ class CdpStoreInfo:
         self.cdp_rawdata_sync_status = 0  # cdp_原始数据同步状态(0-未开始 1-同步历史数据 2-同步增量数据)
         self.history_data_clean_status = 0  # 历史数据清洗状态(0-未开始 1-进行中 2-已完成)
         self.history_member_init_status = 0 # 历史会员初始化状态(0-未开始 1-进行中 2-已完成)
-        self.is_stark_work = 0  # 是否开启作业服务(1-是 0-否)
+        self.is_start_work = 0  # 是否开启作业服务(1-是 0-否)
+        self.work_config = {}  # 作业配置json
 
 
     @classmethod
     def get_field_list(self):
         return [
             'id', 'guid', 'store_name', 'store_icon', 'plat_store_id', 'store_status', 'create_date', 'modify_date', 'plat_telephone_key', 'prefix_status', 'prefix_path', 'business_id', 'seller_nick', 'seller_id', 'platform_id', 'overdue_date', 'access_token', 'extend_info',
-            'description', 'cdp_rawdata_sync_status', 'history_data_clean_status', 'history_member_init_status', 'is_stark_work'
+            'description', 'cdp_rawdata_sync_status', 'history_data_clean_status', 'history_member_init_status', 'is_start_work', 'work_config'
         ]
 
     @classmethod
